/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.dsl.model.android.externalNativeBuild;

import com.android.tools.idea.gradle.dsl.api.android.externalNativeBuild.AbstractBuildModel;
import com.android.tools.idea.gradle.dsl.api.ext.ResolvedPropertyModel;
import com.android.tools.idea.gradle.dsl.model.GradleDslBlockModel;
import com.android.tools.idea.gradle.dsl.parser.elements.GradlePropertiesDslElement;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;


/**
 * Base class for the external native build models like {@link CMakeModelImpl} and {@link NdkBuildModelImpl}.
 */
public abstract class AbstractBuildModelImpl extends GradleDslBlockModel implements AbstractBuildModel {
  @NonNls public static final String PATH = "mPath";
  @NonNls public static final String VERSION = "mVersion";
  // TODO(xof): support buildStagingPath here

  protected AbstractBuildModelImpl(@NotNull GradlePropertiesDslElement dslElement) {
    super(dslElement);
  }

  @Override
  @NotNull
  public ResolvedPropertyModel path() {
    return getFileModelForProperty(PATH);
  }

  @Override
  @NotNull
  public ResolvedPropertyModel version() {
    return getModelForProperty(VERSION);
  }
}
